==> qcad_1.3.3.orig.tar.gz: qcad-1.3.3.orig/rstring.h <==
/***************************************************************************
                          rstring.h  -  description
                             -------------------
    begin                : Mon Sep 27 1999
    copyright            : (C) 1999 by Andreas Mustun
    email                : andrew@ribbonsoft.com
 ***************************************************************************/

/****************************************************************************
** rstring.h 1998/08/29 A. Mustun RibbonSoft
**
** Copyright (C) 1998 RibbonSoft.  All rights reserved.
**
*****************************************************************************/

#ifndef RSTRING_H
#define RSTRING_H

#include <qstring.h>

#include "rprgdef.h"

QString  strGetNickName(QString _fileName);

int      strGetIntFromIniLine(QString _iniLine);
float    strGetFloatFromIniLine(QString _iniLine);
char     strGetCharFromIniLine(QString _iniLine);
QString  strGetStringFromIniLine(QString _iniLine);
bool     strIsValidNcOrderChar(char _ch);
bool     strIsInteger(const char* _str);
bool     strIsSpace(const char* _str);
QString  strFloatToString(float _value);
bool     strReplaceChar(char* _str, char _old, char _new);
void     strGetValuesFromParameterLine(const char* _paraLine, 
                                       bool* _layer, 
                                       bool* _rw,
                                       char* _code,
                                       char* _label,
                                       char* _std,
                                       char* _list);
int      strStepToOrderItem(const char* _order, int _index, bool _overReadEnd=false);
int      strOrderItemLength(const char* _orderItem);

#endif


// EOF

==> qcad_1.4.7.orig.tar.gz: qcad-1.4.7.orig/rstring.h <==
/***************************************************************************
                          rstring.h  -  description
                             -------------------
    begin                : Mon Sep 27 1999
    copyright            : (C) 1999 by Andreas Mustun
    email                : andrew@ribbonsoft.com
 ***************************************************************************/

/****************************************************************************
** rstring.h 1998/08/29 A. Mustun RibbonSoft
**
** Copyright (C) 1998 RibbonSoft.  All rights reserved.
**
*****************************************************************************/

#ifndef RSTRING_H
#define RSTRING_H

#include <qstring.h>

#include "rprgdef.h"

QString  strGetNickName(QString _fileName);

int      strGetIntFromIniLine(QString _iniLine);
double   strGetFloatFromIniLine(QString _iniLine);
char     strGetCharFromIniLine(QString _iniLine);
QString  strGetStringFromIniLine(QString _iniLine);
bool     strIsValidNcOrderChar(char _ch);
bool     strIsInteger(const QString& _str);
bool     strIsSpace(const QString& _str);
QString  strFloatToString(double _value, int _precision=6);
QString  strFloatToString(double _value, double _precision);
bool     strReplaceChar(char* _str, char _old, char _new);
void     strDecodeDxfString(QString& str);
void     strEncodeDxfString(QString& str);
void     strGetValuesFromParameterLine(const char* _paraLine,
                                       bool* _layer, 
                                       bool* _rw,
                                       char* _code,
                                       char* _label,
                                       char* _std,
                                       char* _list);
int      strStepToOrderItem(const char* _order, int _index, bool _overReadEnd=false);
int      strOrderItemLength(const char* _orderItem);

#endif


// EOF
